@@ -2,14 +2,14 @@
 # https://github.com/joke2k/faker/blob/master/faker/providers/person/pl_PL/__init__.py
 
 person_formats_pl_pl = c(
-  '{{first_name}} {{last_name}}',
-  '{{first_name}} {{last_name}}',
-  '{{first_name}} {{last_name}}',
-  '{{first_name}} {{last_name}}',
-  '{{first_name}} {{last_name}}',
-  '{{prefix}} {{first_name}} {{last_name}}',
-  '{{first_name}} {{last_name}}',
-  '{{prefix}} {{first_name}} {{last_name}}'
+  '{{first_names}} {{last_names}}',
+  '{{first_names}} {{last_names}}',
+  '{{first_names}} {{last_names}}',
+  '{{first_names}} {{last_names}}',
+  '{{first_names}} {{last_names}}',
+  '{{prefixes}} {{first_names}} {{last_names}}',
+  '{{first_names}} {{last_names}}',
+  '{{prefixes}} {{first_names}} {{last_names}}'
 )
 
 person_first_names_male_pl_pl = c(
@@ -4072,6 +4072,16 @@ person_prefixes_pl_pl = c('pan', 'pani')
 person_first_names_pl_pl = c(person_first_names_male_pl_pl,
                              person_first_names_female_pl_pl)
 
+person_pl_pl <- list(
+  first_names = person_first_names_pl_pl,
+  first_names_female = person_first_names_female_pl_pl,
+  first_names_male = person_first_names_male_pl_pl,
+  last_names = person_unisex_last_names_pl_pl,
+  last_names_male = person_male_last_names_pl_pl,
+  prefixes = person_prefixes_pl_pl
+)
+
+
 # @classmethod
 # def last_name(cls):
 #   return cls.random_element(cls.unisex_last_names)
